@@ -18,7 +18,7 @@ from pyproj.crs.coordinate_operation import (
     VerticalPerspectiveConversion,
 )
 from pyproj.exceptions import CRSError
-from test.conftest import PROJ_GTE_901, PROJ_LOOSE_VERSION
+from test.conftest import PROJ_LOOSE_VERSION
 
 
 def _to_dict(operation):
@@ -82,13 +82,9 @@ def test_to_cf_transverse_mercator():
     )
     towgs84_test = [-122.74, -34.27, -22.83, -1.884, -3.4, -3.03, -15.62]
     horizontal_datum_name = (
-        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid"
+        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid using "
+        "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
     )
-    if PROJ_GTE_901:
-        horizontal_datum_name = (
-            f"{horizontal_datum_name} using "
-            "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
-        )
     expected_cf = {
         "semi_major_axis": 6378388.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
@@ -221,6 +217,7 @@ def test_cf_from_latlon():
         "grid_mapping_name": "latitude_longitude",
         "geographic_crs_name": "undefined",
         "reference_ellipsoid_name": "undefined",
+        "horizontal_datum_name": "undefined",
     }
     cf_dict = crs.to_cf()
     assert cf_dict.pop("crs_wkt").startswith("GEOGCRS[")
@@ -253,6 +250,7 @@ def test_cf_from_latlon__named():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "geographic_crs_name": "WGS 84",
         "grid_mapping_name": "latitude_longitude",
     }
@@ -360,7 +358,7 @@ def test_cf_rotated_latlon():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "rotated_latitude_longitude",
         "grid_north_pole_latitude": 32.5,
         "grid_north_pole_longitude": 170.0,
@@ -479,6 +477,43 @@ def test_rotated_pole_to_cf():
     _test_roundtrip(expected_cf, "GEOGCRS[")
 
 
+def test_grib_rotated_pole_to_cf():
+    rotated_pole_wkt = """GEOGCRS["Coordinate System imported from GRIB file",
+        BASEGEOGCRS["Coordinate System imported from GRIB file",
+            DATUM["unnamed",
+                ELLIPSOID["Sphere",6371229,0,
+                    LENGTHUNIT["metre",1,
+                        ID["EPSG",9001]]]],
+            PRIMEM["Greenwich",0,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]],
+        DERIVINGCONVERSION["Pole rotation (GRIB convention)",
+            METHOD["Pole rotation (GRIB convention)"],
+            PARAMETER["Latitude of the southern pole (GRIB convention)",-33.443381,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            PARAMETER["Longitude of the southern pole (GRIB convention)",-93.536426,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            PARAMETER["Axis rotation (GRIB convention)",0,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]],
+        CS[ellipsoidal,2],
+            AXIS["latitude",north,
+                ORDER[1],
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            AXIS["longitude",east,
+                ORDER[2],
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]]"""
+    crs = CRS(rotated_pole_wkt)
+    with pytest.warns(UserWarning):
+        cf_dict = crs.to_cf(errcheck=True)
+    assert cf_dict.pop("crs_wkt").startswith("GEOGCRS[")
+    assert not cf_dict
+
+
 def test_cf_lambert_conformal_conic_1sp():
     crs = CRS.from_cf(
         dict(
@@ -495,7 +530,7 @@ def test_cf_lambert_conformal_conic_1sp():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_conformal_conic",
         "longitude_of_central_meridian": 265.0,
         "false_easting": 0.0,
@@ -559,7 +594,7 @@ def test_cf_lambert_conformal_conic_2sp(standard_parallel):
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_conformal_conic",
         "standard_parallel": (25.0, 30.0),
         "latitude_of_projection_origin": 25.0,
@@ -714,7 +749,7 @@ def test_geos_crs_sweep():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "geostationary",
         "sweep_angle_axis": "x",
         "perspective_point_height": 1.0,
@@ -762,7 +797,7 @@ def test_geos_crs_fixed_angle_axis():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "geostationary",
         "sweep_angle_axis": "x",
         "perspective_point_height": 1.0,
@@ -862,7 +897,7 @@ def test_mercator_b():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "mercator",
         "standard_parallel": 21.354,
         "longitude_of_projection_origin": 10.0,
@@ -1166,6 +1201,7 @@ def test_azimuthal_equidistant():
     assert cf_dict.pop("crs_wkt").startswith("PROJCRS[")
     assert cf_dict == expected_cf
     # test roundtrip
+    expected_cf["horizontal_datum_name"] = "World Geodetic System 1984 ensemble"
     _test_roundtrip(expected_cf, "PROJCRS[")
     # test coordinate system
     assert crs.cs_to_cf() == [
@@ -1193,7 +1229,7 @@ def test_lambert_azimuthal_equal_area():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_azimuthal_equal_area",
         "latitude_of_projection_origin": 1.0,
         "longitude_of_projection_origin": 2.0,
@@ -1233,7 +1269,7 @@ def test_lambert_cylindrical_equal_area():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "lambert_cylindrical_equal_area",
         "standard_parallel": 1.0,
         "longitude_of_central_meridian": 2.0,
@@ -1273,7 +1309,7 @@ def test_mercator_a():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "mercator",
         "standard_parallel": 0.0,
         "longitude_of_projection_origin": 2.0,
@@ -1314,7 +1350,7 @@ def test_orthographic():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "orthographic",
         "latitude_of_projection_origin": 1.0,
         "longitude_of_projection_origin": 2.0,
@@ -1354,7 +1390,7 @@ def test_polar_stereographic_a():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "polar_stereographic",
         "latitude_of_projection_origin": 90.0,
         "straight_vertical_longitude_from_pole": 1.0,
@@ -1395,7 +1431,7 @@ def test_polar_stereographic_b():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "polar_stereographic",
         "standard_parallel": 0.0,
         "straight_vertical_longitude_from_pole": 1.0,
@@ -1435,7 +1471,7 @@ def test_stereographic():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "stereographic",
         "latitude_of_projection_origin": 0.0,
         "longitude_of_projection_origin": 1.0,
@@ -1476,7 +1512,7 @@ def test_sinusoidal():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "sinusoidal",
         "longitude_of_projection_origin": 0.0,
         "false_easting": 1.0,
@@ -1515,7 +1551,7 @@ def test_vertical_perspective():
         "reference_ellipsoid_name": "WGS 84",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": "World Geodetic System 1984",
+        "horizontal_datum_name": "World Geodetic System 1984 ensemble",
         "grid_mapping_name": "vertical_perspective",
         "perspective_point_height": 50.0,
         "latitude_of_projection_origin": 0.0,
@@ -1852,7 +1888,7 @@ def test_3d_ellipsoidal_cs_depth():
             "name": "WGS 84 (geographic 3D)",
             "datum": {
                 "type": "GeodeticReferenceFrame",
-                "name": "World Geodetic System 1984",
+                "name": "World Geodetic System 1984 ensemble",
                 "ellipsoid": {
                     "name": "WGS 84",
                     "semi_major_axis": 6378137,
